# transformation-algebra

The project has been renamed to `transforge`. You can find it at 
<https://pypi.org/project/transforge/>. Source code is at 
<https://github.com/quangis/transforge/>. This package is deprecated.
